==> pykeen-1.0.2.tar.gz: pykeen-1.0.2/src/pykeen/datasets/openbiolink.py <==
# -*- coding: utf-8 -*-

"""The OpenBioLink dataset.

Get a summary with ``python -m pykeen.datasets.openbiolink``
"""

import logging

import click

from .base import PackedZipRemoteDataSet

__all__ = [
    'OpenBioLink',
    'OpenBioLinkF1',
    'OpenBioLinkF2',
    'OpenBioLinkLQ',
]

HQ_URL = 'https://samwald.info/res/OpenBioLink_2020_final/HQ_DIR.zip'
F1_URL = 'https://github.com/PyKEEN/pykeen-openbiolink-benchmark/raw/master/filter_1/openbiolink_f1.zip'
F2_URL = 'https://github.com/PyKEEN/pykeen-openbiolink-benchmark/raw/master/filter_2/openbiolink_f2.zip'
LQ_URL = 'https://samwald.info/res/OpenBioLink_2020_final/ALL_DIR.zip'


class OpenBioLink(PackedZipRemoteDataSet):
    """The OpenBioLink dataset.

    OpenBioLink is an open-source, reproducible framework for generating biological
    knowledge graphs for benchmarking link prediction. It is available on GitHub
    at https://github.com/openbiolink/openbiolink and published in [breit2020]_. There are four
    available data sets - this class represents the high quality, directed set.

    .. [breit2020] Breit, A. (2020) `OpenBioLink: A benchmarking framework for large-scale biomedical link
       prediction <https://doi.org/10.1093/bioinformatics/btaa274>`_, *Bioinformatics*
    """

    def __init__(self, create_inverse_triples: bool = False, eager: bool = False):
        super().__init__(
            url=HQ_URL,
            name='HQ_DIR.zip',
            relative_training_path='HQ_DIR/train_test_data/train_sample.csv',
            relative_testing_path='HQ_DIR/train_test_data/test_sample.csv',
            relative_validation_path='HQ_DIR/train_test_data/val_sample.csv',
            eager=eager,
            create_inverse_triples=create_inverse_triples,
        )


class OpenBioLinkF1(PackedZipRemoteDataSet):
    """The PyKEEN First Filtered OpenBioLink 2020 Dataset."""

    def __init__(self, create_inverse_triples: bool = False, eager: bool = False):
        super().__init__(
            url=F1_URL,
            name='openbiolink_f1.zip',
            relative_training_path='train.tsv',
            relative_testing_path='test.tsv',
            relative_validation_path='val.tsv',
            eager=eager,
            create_inverse_triples=create_inverse_triples,
        )


class OpenBioLinkF2(PackedZipRemoteDataSet):
    """The PyKEEN Second Filtered OpenBioLink 2020 Dataset."""

    def __init__(self, create_inverse_triples: bool = False, eager: bool = False):
        super().__init__(
            url=F2_URL,
            name='openbiolink_f2.zip',
            relative_training_path='train.tsv',
            relative_testing_path='test.tsv',
            relative_validation_path='val.tsv',
            eager=eager,
            create_inverse_triples=create_inverse_triples,
        )


class OpenBioLinkLQ(PackedZipRemoteDataSet):
    """The low-quality variant of the OpenBioLink dataset."""

    def __init__(self, create_inverse_triples: bool = False, eager: bool = False):
        super().__init__(
            url=LQ_URL,
            name='ALL_DIR.zip',
            relative_training_path='ALL_DIR/train_test_data/train_sample.csv',
            relative_testing_path='ALL_DIR/train_test_data/test_sample.csv',
            relative_validation_path='ALL_DIR/train_test_data/val_sample.csv',
            eager=eager,
            create_inverse_triples=create_inverse_triples,
        )


@click.command()
def _main():
    ds = OpenBioLink()
    click.echo(ds.summary_str())


if __name__ == '__main__':
    logging.basicConfig(level=logging.INFO)
    _main()

==> pykeen-1.3.0.tar.gz: pykeen-1.3.0/src/pykeen/datasets/openbiolink.py <==
# -*- coding: utf-8 -*-

"""The OpenBioLink dataset.

Get a summary with ``python -m pykeen.datasets.openbiolink``
"""

import logging

import click

from .base import PackedZipRemoteDataset

__all__ = [
    'OpenBioLink',
    'OpenBioLinkF1',
    'OpenBioLinkF2',
    'OpenBioLinkLQ',
]

HQ_URL = 'https://samwald.info/res/OpenBioLink_2020_final/HQ_DIR.zip'
F1_URL = 'https://github.com/PyKEEN/pykeen-openbiolink-benchmark/raw/master/filter_1/openbiolink_f1.zip'
F2_URL = 'https://github.com/PyKEEN/pykeen-openbiolink-benchmark/raw/master/filter_2/openbiolink_f2.zip'
LQ_URL = 'https://samwald.info/res/OpenBioLink_2020_final/ALL_DIR.zip'


class OpenBioLink(PackedZipRemoteDataset):
    """The OpenBioLink dataset.

    OpenBioLink is an open-source, reproducible framework for generating biological
    knowledge graphs for benchmarking link prediction. It is available on GitHub
    at https://github.com/openbiolink/openbiolink and published in [breit2020]_. There are four
    available datasets - this class represents the high quality, directed set.

    .. [breit2020] Breit, A. (2020) `OpenBioLink: A benchmarking framework for large-scale biomedical link
       prediction <https://doi.org/10.1093/bioinformatics/btaa274>`_, *Bioinformatics*
    """

    def __init__(self, create_inverse_triples: bool = False, **kwargs):
        """Initialize the OpenBioLink dataset.

        :param create_inverse_triples: Should inverse triples be created? Defaults to false.
        :param kwargs: keyword arguments passed to :class:`pykeen.datasets.base.PackedZipRemoteDataset`.
        """
        super().__init__(
            url=HQ_URL,
            name='HQ_DIR.zip',
            relative_training_path='HQ_DIR/train_test_data/train_sample.csv',
            relative_testing_path='HQ_DIR/train_test_data/test_sample.csv',
            relative_validation_path='HQ_DIR/train_test_data/val_sample.csv',
            create_inverse_triples=create_inverse_triples,
            **kwargs,
        )


class OpenBioLinkF1(PackedZipRemoteDataset):
    """The PyKEEN First Filtered OpenBioLink 2020 Dataset."""

    def __init__(self, create_inverse_triples: bool = False, **kwargs):
        """Initialize the OpenBioLink (Filter-1) dataset.

        :param create_inverse_triples: Should inverse triples be created? Defaults to false.
        :param kwargs: keyword arguments passed to :class:`pykeen.datasets.base.PackedZipRemoteDataset`.
        """
        super().__init__(
            url=F1_URL,
            name='openbiolink_f1.zip',
            relative_training_path='train.tsv',
            relative_testing_path='test.tsv',
            relative_validation_path='val.tsv',
            create_inverse_triples=create_inverse_triples,
            **kwargs,
        )


class OpenBioLinkF2(PackedZipRemoteDataset):
    """The PyKEEN Second Filtered OpenBioLink 2020 Dataset."""

    def __init__(self, create_inverse_triples: bool = False, **kwargs):
        """Initialize the OpenBioLink (Filter-2) dataset.

        :param create_inverse_triples: Should inverse triples be created? Defaults to false.
        :param kwargs: keyword arguments passed to :class:`pykeen.datasets.base.PackedZipRemoteDataset`.
        """
        super().__init__(
            url=F2_URL,
            name='openbiolink_f2.zip',
            relative_training_path='train.tsv',
            relative_testing_path='test.tsv',
            relative_validation_path='val.tsv',
            create_inverse_triples=create_inverse_triples,
            **kwargs,
        )


class OpenBioLinkLQ(PackedZipRemoteDataset):
    """The low-quality variant of the OpenBioLink dataset."""

    def __init__(self, create_inverse_triples: bool = False, **kwargs):
        """Initialize the OpenBioLink (low quality) dataset.

        :param create_inverse_triples: Should inverse triples be created? Defaults to false.
        :param kwargs: keyword arguments passed to :class:`pykeen.datasets.base.PackedZipRemoteDataset`.
        """
        super().__init__(
            url=LQ_URL,
            name='ALL_DIR.zip',
            relative_training_path='ALL_DIR/train_test_data/train_sample.csv',
            relative_testing_path='ALL_DIR/train_test_data/test_sample.csv',
            relative_validation_path='ALL_DIR/train_test_data/val_sample.csv',
            create_inverse_triples=create_inverse_triples,
            **kwargs,
        )


@click.command()
def _main():
    ds = OpenBioLink()
    click.echo(ds.summary_str())


if __name__ == '__main__':
    logging.basicConfig(level=logging.INFO)
    _main()
